@@ -277,6 +277,7 @@ macro_rules! update_cache_info {
         use indicatif::HumanCount;
 
         let cache_instance = $cache_instance.lock();
+        #[allow(clippy::significant_drop_tightening)]
         match cache_instance {
             Ok(cache) => {
                 let cache_size = cache.cache_size();
@@ -525,7 +526,7 @@ fn create_dir_all_threadsafe(path: &Path) -> std::io::Result<()> {
 }
 
 /// Represents a filename template of the form `"{}.csv"`, where `"{}"` is
-/// the splace to insert the part of the filename generated by `qsv`.
+/// the place to insert the part of the filename generated by `qsv`.
 #[cfg(any(feature = "full", feature = "lite"))]
 #[derive(Clone)]
 pub struct FilenameTemplate {
@@ -1048,7 +1049,7 @@ impl ColumnNameParser {
 }
 
 pub fn round_num(dec_f64: f64, places: u32) -> String {
-    use rust_decimal::prelude::*;
+    use rust_decimal::{Decimal, RoundingStrategy};
 
     // use from_f64_retain, so we have all the excess bits before rounding with
     // round_dp_with_strategy as from_f64 will prematurely round when it drops the excess bits
