@@ -1,3 +1,5 @@
+use newline_converter::dos2unix;
+
 use crate::workdir::Workdir;
 
 #[test]
@@ -372,7 +374,7 @@ BEGIN {
     amount_array = {};
     csv_indexed = qsv_autoindex();
 
-    us_states_lookup_headers = qsv_register_lookup("us_states", "us-states-lookup.csv")
+    us_states_lookup_headers = qsv_register_lookup("us_states", "us-states-lookup.csv", 1000)
 
     -- note how we use the qsv_log function to log to the qsv log file
     qsv_log("debug", " _INDEX:", _INDEX, " _ROWCOUNT:", _ROWCOUNT, " csv_indexed:", csv_indexed)
@@ -464,7 +466,7 @@ BEGIN {
     csv_indexed = qsv_autoindex();
 
     us_states_lookup_headers = qsv_register_lookup("us_states", 
-      "https://raw.githubusercontent.com/jqnatividad/qsv/master/resources/test/us-states-lookup.csv")
+      "https://raw.githubusercontent.com/jqnatividad/qsv/master/resources/test/us-states-lookup.csv", 1000)
 
     -- note how we use the qsv_log function to log to the qsv log file
     qsv_log("debug", " _INDEX:", _INDEX, " _ROWCOUNT:", _ROWCOUNT, " csv_indexed:", csv_indexed)
@@ -556,7 +558,7 @@ BEGIN {
     csv_indexed = qsv_autoindex();
 
     us_states_lookup_headers = qsv_register_lookup("us_states", 
-      "dathere://us-states-example.csv")
+      "dathere://us-states-example.csv", 1000)
 
     -- note how we use the qsv_log function to log to the qsv log file
     qsv_log("debug", " _INDEX:", _INDEX, " _ROWCOUNT:", _ROWCOUNT, " csv_indexed:", csv_indexed)
@@ -641,7 +643,7 @@ fn luau_register_lookup_table_ckan() {
         r#"
 BEGIN {
 
-    cityscore_headers = qsv_register_lookup("cityscore", "ckan://CityScore Summary?")
+    cityscore_headers = qsv_register_lookup("cityscore", "ckan://CityScore Summary?", 1000)
 
     function spairs(t, order)
         -- collect the keys
@@ -688,7 +690,7 @@ END {
     cmd.arg("map")
         .arg("previous_month_score")
         .arg("-x")
-        .arg("file:testlookup.luau")
+        .arg("testlookup.luau")
         .arg("--ckan-api")
         .arg("https://data.boston.gov/api/3/action")
         .arg("data.csv");
@@ -750,7 +752,7 @@ fn luau_qsv_break() {
     );
 
     wrk.create_from_string(
-        "testbreak.luau",
+        "testbreak.lua",
         r#"
 BEGIN {
     -- this is the BEGIN block, which is executed once at the beginning
@@ -787,7 +789,7 @@ END {
     cmd.arg("map")
         .arg("Running Total")
         .arg("-x")
-        .arg("file:testbreak.luau")
+        .arg("testbreak.lua")
         .arg("data.csv");
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
@@ -821,7 +823,7 @@ fn luau_qsv_skip() {
     );
 
     wrk.create_from_string(
-        "testbreak.luau",
+        "testbreak.LUAU",
         r#"
 BEGIN {
     -- this is the BEGIN block, which is executed once at the beginning
@@ -858,7 +860,7 @@ END {
     cmd.arg("map")
         .arg("Running Total")
         .arg("-x")
-        .arg("file:testbreak.luau")
+        .arg("testbreak.LUAU")
         .arg("data.csv");
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
@@ -877,6 +879,221 @@ END {
     wrk.assert_success(&mut cmd);
 }
 
+#[test]
+fn luau_qsv_cmd() {
+    let wrk = Workdir::new("luau_qsv_cmd_test");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "Amount"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "7"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testqsvcmd.Lua",
+        r#"
+BEGIN {
+    -- this is the BEGIN block, which is executed once at the beginning
+    -- where we typically initialize variables
+    running_total = 0;
+    grand_total = 0;
+    amount_array = {};
+    qsv_writefile("count.txt", "_NEWFILE!");
+}!
+
+-- this is the MAIN script, which is executed for each row
+-- note how we use the _IDX special variable to get the row index
+
+amount_array[_IDX] = Amount;
+running_total = running_total + Amount;
+grand_total = grand_total + running_total;
+-- running_total is the value we "map" to the "Running Total" column of each row
+return running_total;
+
+END {
+    -- and this is the END block, which is executed once at the end
+    -- note how we use the _ROWCOUNT special variable to get the number of rows
+    min_amount = math.min(unpack(amount_array));
+    max_amount = math.max(unpack(amount_array));
+
+    qsv_cmd_output = qsv_cmd("count data.csv");
+    qsv_writefile("count.txt", qsv_cmd_output.stdout);
+    return (`Min/Max: {min_amount}/{max_amount} Grand total of {_IDX - 1} rows: {grand_total}`);
+}!
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("map")
+        .arg("Running Total")
+        .arg("-x")
+        .arg("testqsvcmd.Lua")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "Amount", "Running Total"],
+        svec!["a", "13", "13"],
+        svec!["b", "24", "37"],
+        svec!["c", "72", "109"],
+        svec!["d", "7", "116"],
+    ];
+    assert_eq!(got, expected);
+
+    let end = wrk.output_stderr(&mut cmd);
+    let expected_end = "Min/Max: 7/72 Grand total of 3 rows: 275\n".to_string();
+    assert_eq!(end, expected_end);
+
+    let table_txt = wrk.read_to_string("count.txt");
+    let expected_table_txt = "4\n";
+    assert_eq!(table_txt, expected_table_txt);
+
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn luau_qsv_invalid_shellcmd() {
+    let wrk = Workdir::new("luau_qsv_invalid_shellcmd");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "Amount"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "7"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testqsvcmd.luau",
+        r#"
+BEGIN {
+    -- this is the BEGIN block, which is executed once at the beginning
+    -- where we typically initialize variables
+    running_total = 0;
+    grand_total = 0;
+    amount_array = {};
+    qsv_writefile("echo.txt", "_NEWFILE!");
+}!
+
+-- this is the MAIN script, which is executed for each row
+-- note how we use the _IDX special variable to get the row index
+
+amount_array[_IDX] = Amount;
+running_total = running_total + Amount;
+grand_total = grand_total + running_total;
+-- running_total is the value we "map" to the "Running Total" column of each row
+return running_total;
+
+END {
+    -- and this is the END block, which is executed once at the end
+    -- note how we use the _ROWCOUNT special variable to get the number of rows
+    min_amount = math.min(unpack(amount_array));
+    max_amount = math.max(unpack(amount_array));
+
+    qsv_shellcmd_output = qsv_shellcmd("rm","-rf *");
+    qsv_writefile("echo.txt", qsv_shellcmd_output.stderr);
+    return (`Min/Max: {min_amount}/{max_amount} Grand total of {_IDX - 1} rows: {grand_total}`);
+}!
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("map")
+        .arg("Running Total")
+        .arg("-x")
+        .arg("file:testqsvcmd.luau")
+        .arg("data.csv");
+
+    let output_stderr = wrk.output_stderr(&mut cmd);
+    assert!(
+        output_stderr.starts_with("<ERROR>")
+            && output_stderr.contains("runtime error: Invalid shell command: \"rm\".")
+    );
+
+    wrk.assert_success(&mut cmd);
+}
+
+#[test]
+fn luau_qsv_shellcmd() {
+    let wrk = Workdir::new("luau_qsv_shellcmd");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "Amount"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "7"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testqsvcmd.luau",
+        r#"
+BEGIN {
+    -- this is the BEGIN block, which is executed once at the beginning
+    -- where we typically initialize variables
+    running_total = 0;
+    grand_total = 0;
+    amount_array = {};
+    qsv_writefile("echo.txt", "_NEWFILE!");
+}!
+
+-- this is the MAIN script, which is executed for each row
+-- note how we use the _IDX special variable to get the row index
+
+amount_array[_IDX] = Amount;
+running_total = running_total + Amount;
+grand_total = grand_total + running_total;
+-- running_total is the value we "map" to the "Running Total" column of each row
+return running_total;
+
+END {
+    -- and this is the END block, which is executed once at the end
+    -- note how we use the _ROWCOUNT special variable to get the number of rows
+    min_amount = math.min(unpack(amount_array));
+    max_amount = math.max(unpack(amount_array));
+
+    qsv_shellcmd_output = qsv_shellcmd("echo","the quick brown fox jumped over the lazy dog");
+    qsv_writefile("echo.txt", qsv_shellcmd_output.stdout);
+    return (`Min/Max: {min_amount}/{max_amount} Grand total of {_IDX - 1} rows: {grand_total}`);
+}!
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("map")
+        .arg("Running Total")
+        .arg("-x")
+        .arg("file:testqsvcmd.luau")
+        .arg("data.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "Amount", "Running Total"],
+        svec!["a", "13", "13"],
+        svec!["b", "24", "37"],
+        svec!["c", "72", "109"],
+        svec!["d", "7", "116"],
+    ];
+    assert_eq!(got, expected);
+
+    let echo_text = wrk.read_to_string("echo.txt");
+    let expected_echo_text = "the quick brown fox jumped over the lazy dog";
+    assert_eq!(
+        dos2unix(&echo_text).trim_end(),
+        dos2unix(expected_echo_text).trim_end()
+    );
+
+    wrk.assert_success(&mut cmd);
+}
+
 #[test]
 fn luau_insertrecord() {
     let wrk = Workdir::new("luau_insertrecord");
@@ -1633,16 +1850,6 @@ fn luau_map_error() {
         .arg("math.dancefloor(number / 2)")
         .arg("data.csv");
 
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = vec![
-        svec!["letter", "number", "div"],
-        svec!["a", "13", "<ERROR>"],
-        svec!["b", "24", "<ERROR>"],
-        svec!["c", "72", "<ERROR>"],
-        svec!["d", "7", "<ERROR>"],
-    ];
-    assert_eq!(got, expected);
-
     wrk.assert_err(&mut cmd);
     let stderr_string = wrk.output_stderr(&mut cmd);
     assert!(stderr_string.ends_with("Luau errors encountered: 4\n"));
@@ -1919,3 +2126,103 @@ fn luau_filter_num() {
     ];
     assert_eq!(got, expected);
 }
+
+#[test]
+fn luau_envvars() {
+    let wrk = Workdir::new("luau_envvars");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "number"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "-7"],
+            svec!["e", "0"],
+            svec!["f", "42"],
+            svec!["g", "0.0"],
+            svec!["h", "3.14"],
+            svec!["i", "0.000123"],
+            svec!["j", "-7.01"],
+            svec!["k", "0.0000"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testenvvar.luau",
+        r#"
+BEGIN {
+    qsv_setenv("TESTENVVAR", "11");
+}!
+
+local limit = qsv_getenv("TESTENVVAR")
+return tonumber(number) > tonumber(limit)
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("filter")
+        .arg("-x")
+        .arg("file:testenvvar.luau")
+        .arg("data.csv");
+
+    let testenvvar = std::env::var("TESTENVVAR").unwrap_or_else(|_| "NOT SET".to_string());
+    assert_eq!(testenvvar, "NOT SET");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "number"],
+        svec!["a", "13"],
+        svec!["b", "24"],
+        svec!["c", "72"],
+        svec!["f", "42"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn luau_envvars_external() {
+    let wrk = Workdir::new("luau_envvars_external");
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["letter", "number"],
+            svec!["a", "13"],
+            svec!["b", "24"],
+            svec!["c", "72"],
+            svec!["d", "-7"],
+            svec!["e", "0"],
+            svec!["f", "42"],
+            svec!["g", "0.0"],
+            svec!["h", "3.14"],
+            svec!["i", "0.000123"],
+            svec!["j", "-7.01"],
+            svec!["k", "0.0000"],
+        ],
+    );
+
+    wrk.create_from_string(
+        "testenvvar.luau",
+        r#"
+local limit = qsv_getenv("TESTENVVAR")
+return tonumber(number) > tonumber(limit)
+"#,
+    );
+
+    let mut cmd = wrk.command("luau");
+    cmd.arg("filter")
+        .arg("-x")
+        .arg("file:testenvvar.luau")
+        .arg("data.csv")
+        .env("TESTENVVAR", "10");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["letter", "number"],
+        svec!["a", "13"],
+        svec!["b", "24"],
+        svec!["c", "72"],
+        svec!["f", "42"],
+    ];
+    assert_eq!(got, expected);
+}
