@@ -1,6 +1,4 @@
-use crate::workdir::Workdir;
-
-use crate::{qcheck, Csv, CsvData};
+use crate::{qcheck, workdir::Workdir, Csv, CsvData};
 
 fn prop_reverse(name: &str, rows: CsvData, headers: bool) -> bool {
     let wrk = Workdir::new(name);
