@@ -788,6 +788,24 @@ fn stats_typesonly_with_dates() {
     assert_eq!(dos2unix(&got), dos2unix(&expected).trim_end());
 }
 
+#[test]
+fn stats_everything_utf8_japanese_issue817() {
+    let wrk = Workdir::new("stats_everything_utf8_japanese");
+    let test_file = wrk.load_test_file("utf8-japanesedata.csv");
+
+    let mut cmd = wrk.command("stats");
+    cmd.arg("--everything").arg(test_file);
+
+    wrk.assert_success(&mut cmd);
+    // TODO: for now, let's just make sure it doesn't crash
+    // comparing utf8 output is a bit tricky, with git line endings
+    // and other things
+
+    // let got: String = wrk.stdout(&mut cmd);
+    // let expected = wrk.load_test_resource("utf8-japanesedata-stats-everything.csv");
+    // assert_eq!(dos2unix(&got).trim_end(), dos2unix(&expected).trim_end());
+}
+
 #[test]
 fn stats_leading_zero_handling() {
     let wrk = Workdir::new("stats");
